# corona.py
An asynchronous wrapper for the [NovelCOVID API](https://github.com/NovelCOVID/API) written in Python.

This is designed for bots using [discord.py](https://github.com/Rapptz/discord.py) with optional discord.py plugin. 

# Requirements
 - Python 3.6 or above
 - aiohttp (`python3 -m pip install -U aiohttp`)

# Installation
### Using pip (recommended)
 - `python3 -m pip install -U corona_api`
 
# Support
Get support for this over on [Discord](https://corona.lmao.ninja/invite) and ping NANI#0001.